@@ -315,7 +315,7 @@ function octavia_configure {
     configure_keystone_authtoken_middleware $OCTAVIA_CONF octavia
 
     # Ensure config is set up properly for authentication as admin
-    iniset $OCTAVIA_CONF service_auth auth_url $OS_AUTH_URL
+    iniset $OCTAVIA_CONF service_auth auth_url $KEYSTONE_SERVICE_URI
     iniset $OCTAVIA_CONF service_auth auth_type password
     iniset $OCTAVIA_CONF service_auth username $OCTAVIA_USERNAME
     iniset $OCTAVIA_CONF service_auth password $OCTAVIA_PASSWORD
