@@ -56,6 +56,7 @@ class BaseOS(object):
     def write_interface_file(self, interface, ip_address, prefixlen):
         interface = interface_file.InterfaceFile(
             name=interface,
+            if_type=consts.LO,
             addresses=[{
                 "address": ip_address,
                 "prefixlen": prefixlen
@@ -66,7 +67,7 @@ class BaseOS(object):
     def write_vip_interface_file(self, interface, vip, ip_version,
                                  prefixlen, gateway,
                                  mtu, vrrp_ip,
-                                 host_routes):
+                                 host_routes, fixed_ips=None):
         vip_interface = interface_file.VIPInterfaceFile(
             name=interface,
             mtu=mtu,
@@ -76,6 +77,7 @@ class BaseOS(object):
             gateway=gateway,
             vrrp_ip=vrrp_ip,
             host_routes=host_routes,
+            fixed_ips=fixed_ips,
             topology=CONF.controller_worker.loadbalancer_topology)
         vip_interface.write()
 
@@ -87,38 +89,23 @@ class BaseOS(object):
         port_interface.write()
 
     @classmethod
-    def _bring_if_up(cls, interface, what):
+    def bring_interface_up(cls, interface, name):
         cmd = ("ip netns exec {ns} amphora-interface up {params}".format(
             ns=consts.AMPHORA_NAMESPACE, params=interface))
         LOG.debug("Executing: %s", cmd)
         try:
             out = subprocess.check_output(cmd.split(),
                                           stderr=subprocess.STDOUT)
-            LOG.debug(out)
+            for line in out.decode('utf-8').split('\n'):
+                LOG.debug(line)
         except subprocess.CalledProcessError as e:
             LOG.error('Failed to set up %s due to error: %s %s', interface,
                       e, e.output)
             raise exceptions.HTTPException(
                 response=webob.Response(json=dict(
-                    message='Error plugging {0}'.format(what),
+                    message='Error plugging {0}'.format(name),
                     details=e.output), status=500))
 
-    @classmethod
-    def _bring_if_down(cls, interface):
-        cmd = ("ip netns exec {ns} amphora-interface down {params}".format(
-            ns=consts.AMPHORA_NAMESPACE, params=interface))
-        LOG.debug("Executing: %s", cmd)
-        try:
-            subprocess.check_output(cmd.split(), stderr=subprocess.STDOUT)
-        except subprocess.CalledProcessError as e:
-            LOG.info('Ignoring failure to set %s down due to error: %s %s',
-                     interface, e, e.output)
-
-    @classmethod
-    def bring_interfaces_up(cls, ip, primary_interface):
-        cls._bring_if_down(primary_interface)
-        cls._bring_if_up(primary_interface, 'VIP')
-
 
 class Ubuntu(BaseOS):
 
