@@ -75,7 +75,7 @@ def call_provider(provider, driver_method, *args, **kwargs):
             prov=provider, user_msg=e.user_fault_string)
     except Exception as e:
         LOG.exception("Provider '%s' raised an unknown error: %s",
-                      provider, e)
+                      provider, str(e))
         raise exceptions.ProviderDriverError(prov=provider, user_msg=e)
 
 
@@ -206,6 +206,10 @@ def _get_secret_data(cert_manager, project_id, secret_ref, for_delete=False):
             secret_data = None
         else:
             raise exceptions.CertificateRetrievalException(ref=secret_ref)
+    # We need to have json convertible data for storing it in
+    # persistence jobboard backend.
+    if isinstance(secret_data, bytes):
+        return secret_data.decode()
     return secret_data
 
 
@@ -268,11 +272,13 @@ def listener_dict_to_provider_dict(listener_dict, for_delete=False):
 
         if listener_obj.client_ca_tls_certificate_id:
             cert = _get_secret_data(cert_manager, listener_obj.project_id,
-                                    listener_obj.client_ca_tls_certificate_id)
+                                    listener_obj.client_ca_tls_certificate_id,
+                                    for_delete=for_delete)
             new_listener_dict['client_ca_tls_container_data'] = cert
         if listener_obj.client_crl_container_id:
             crl_file = _get_secret_data(cert_manager, listener_obj.project_id,
-                                        listener_obj.client_crl_container_id)
+                                        listener_obj.client_crl_container_id,
+                                        for_delete=for_delete)
             new_listener_dict['client_crl_container_data'] = crl_file
 
     # Format the allowed_cidrs
@@ -390,12 +396,14 @@ def pool_dict_to_provider_dict(pool_dict, for_delete=False):
 
         if pool_obj.ca_tls_certificate_id:
             cert = _get_secret_data(cert_manager, pool_obj.project_id,
-                                    pool_obj.ca_tls_certificate_id)
+                                    pool_obj.ca_tls_certificate_id,
+                                    for_delete=for_delete)
             new_pool_dict['ca_tls_container_data'] = cert
 
         if pool_obj.crl_container_id:
             crl_file = _get_secret_data(cert_manager, pool_obj.project_id,
-                                        pool_obj.crl_container_id)
+                                        pool_obj.crl_container_id,
+                                        for_delete=for_delete)
             new_pool_dict['crl_container_data'] = crl_file
 
     # Remove the DB back references
