@@ -23,7 +23,6 @@ from cryptography.hazmat.primitives import serialization
 from cryptography import x509
 from oslo_config import cfg
 from oslo_log import log as logging
-import six
 
 from octavia.certificates.common import local as local_common
 from octavia.certificates.generator import cert_gen
@@ -46,21 +45,23 @@ class LocalCertGenerator(cert_gen.CertGenerator):
         if not ca_cert:
             LOG.info("Using CA Certificate from config.")
             try:
-                ca_cert = open(CONF.certificates.ca_certificate, 'rb').read()
-            except IOError:
+                with open(CONF.certificates.ca_certificate, 'rb') as fp:
+                    fp.read()
+            except IOError as e:
                 raise exceptions.CertificateGenerationException(
                     msg="Failed to load CA Certificate {0}."
                         .format(CONF.certificates.ca_certificate)
-                )
+                ) from e
         if not ca_key:
             LOG.info("Using CA Private Key from config.")
             try:
-                ca_key = open(CONF.certificates.ca_private_key, 'rb').read()
-            except IOError:
+                with open(CONF.certificates.ca_private_key, 'rb') as fp:
+                    fp.read()
+            except IOError as e:
                 raise exceptions.CertificateGenerationException(
                     msg="Failed to load CA Private Key {0}."
                         .format(CONF.certificates.ca_private_key)
-                )
+                ) from e
         if not ca_key_pass:
             ca_key_pass = CONF.certificates.ca_private_key_passphrase
             if ca_key_pass:
@@ -93,10 +94,10 @@ class LocalCertGenerator(cert_gen.CertGenerator):
             ca_digest = CONF.certificates.signing_digest
         try:
             algorithm = getattr(hashes, ca_digest.upper())()
-        except AttributeError:
+        except AttributeError as e:
             raise crypto_exceptions.UnsupportedAlgorithm(
                 "Supplied digest method not found: %s" % ca_digest
-            )
+            ) from e
 
         if not ca_cert:
             with open(CONF.certificates.ca_certificate, 'rb') as f:
@@ -186,7 +187,6 @@ class LocalCertGenerator(cert_gen.CertGenerator):
 
     @classmethod
     def _generate_csr(cls, cn, private_key, passphrase=None):
-        cn = six.text_type(cn)
         pk = serialization.load_pem_private_key(
             data=private_key, password=passphrase,
             backend=backends.default_backend())
