@@ -14,6 +14,9 @@
 #
 
 import copy
+from typing import List
+from typing import Optional
+
 from cryptography import fernet
 from oslo_config import cfg
 from oslo_log import log as logging
@@ -99,10 +102,19 @@ class AmpListenersUpdate(BaseAmphoraTask):
 class AmphoraIndexListenerUpdate(BaseAmphoraTask):
     """Task to update the listeners on one amphora."""
 
-    def execute(self, loadbalancer, amphora_index, amphorae, timeout_dict=()):
+    def execute(self, loadbalancer, amphora_index, amphorae,
+                amphorae_status: dict, new_amphora_id: str, timeout_dict=()):
         # Note, we don't want this to cause a revert as it may be used
         # in a failover flow with both amps failing. Skip it and let
         # health manager fix it.
+
+        amphora_id = amphorae[amphora_index].get(constants.ID)
+        amphora_status = amphorae_status.get(amphora_id, {})
+        if amphora_status.get(constants.UNREACHABLE):
+            LOG.warning("Skipping listener update because amphora %s "
+                        "is not reachable.", amphora_id)
+            return
+
         try:
             # TODO(johnsom) Optimize this to use the dicts and not need the
             #               DB lookups
@@ -115,12 +127,14 @@ class AmphoraIndexListenerUpdate(BaseAmphoraTask):
             self.amphora_driver.update_amphora_listeners(
                 db_lb, db_amp, timeout_dict)
         except Exception as e:
-            amphora_id = amphorae[amphora_index].get(constants.ID)
             LOG.error('Failed to update listeners on amphora %s. Skipping '
                       'this amphora as it is failing to update due to: %s',
                       amphora_id, str(e))
-            self.amphora_repo.update(db_apis.get_session(), amphora_id,
-                                     status=constants.ERROR)
+            # Update only the status of the newly created amphora during the
+            # failover
+            if amphora_id == new_amphora_id:
+                self.amphora_repo.update(db_apis.get_session(), amphora_id,
+                                         status=constants.ERROR)
 
 
 class ListenersUpdate(BaseAmphoraTask):
@@ -177,10 +191,18 @@ class AmphoraIndexListenersReload(BaseAmphoraTask):
     """Task to reload all listeners on an amphora."""
 
     def execute(self, loadbalancer, amphora_index, amphorae,
-                timeout_dict=None):
+                amphorae_status: dict, new_amphora_id: str, timeout_dict=None):
         """Execute listener reload routines for listeners on an amphora."""
         if amphorae is None:
             return
+
+        amphora_id = amphorae[amphora_index].get(constants.ID)
+        amphora_status = amphorae_status.get(amphora_id, {})
+        if amphora_status.get(constants.UNREACHABLE):
+            LOG.warning("Skipping listener reload because amphora %s "
+                        "is not reachable.", amphora_id)
+            return
+
         # TODO(johnsom) Optimize this to use the dicts and not need the
         #               DB lookups
         db_amp = self.amphora_repo.get(
@@ -192,12 +214,14 @@ class AmphoraIndexListenersReload(BaseAmphoraTask):
             try:
                 self.amphora_driver.reload(db_lb, db_amp, timeout_dict)
             except Exception as e:
-                amphora_id = amphorae[amphora_index][constants.ID]
                 LOG.warning('Failed to reload listeners on amphora %s. '
                             'Skipping this amphora as it is failing to '
                             'reload due to: %s', amphora_id, str(e))
-                self.amphora_repo.update(db_apis.get_session(), amphora_id,
-                                         status=constants.ERROR)
+                # Update only the status of the newly created amphora during
+                # the failover
+                if amphora_id == new_amphora_id:
+                    self.amphora_repo.update(db_apis.get_session(), amphora_id,
+                                             status=constants.ERROR)
 
 
 class ListenerDelete(BaseAmphoraTask):
@@ -421,8 +445,15 @@ class AmphoraUpdateVRRPInterface(BaseAmphoraTask):
 class AmphoraIndexUpdateVRRPInterface(BaseAmphoraTask):
     """Task to get and update the VRRP interface device name from amphora."""
 
-    def execute(self, amphora_index, amphorae, timeout_dict=None):
+    def execute(self, amphora_index, amphorae, amphorae_status: dict,
+                new_amphora_id: str, timeout_dict=None):
         amphora_id = amphorae[amphora_index][constants.ID]
+        amphora_status = amphorae_status.get(amphora_id, {})
+        if amphora_status.get(constants.UNREACHABLE):
+            LOG.warning("Skipping VRRP interface update because amphora %s "
+                        "is not reachable.", amphora_id)
+            return None
+
         try:
             # TODO(johnsom) Optimize this to use the dicts and not need the
             #               DB lookups
@@ -435,8 +466,11 @@ class AmphoraIndexUpdateVRRPInterface(BaseAmphoraTask):
             LOG.error('Failed to get amphora VRRP interface on amphora '
                       '%s. Skipping this amphora as it is failing due to: '
                       '%s', amphora_id, str(e))
-            self.amphora_repo.update(db_apis.get_session(), amphora_id,
-                                     status=constants.ERROR)
+            # Update only the status of the newly created amphora during the
+            # failover
+            if amphora_id == new_amphora_id:
+                self.amphora_repo.update(db_apis.get_session(), amphora_id,
+                                         status=constants.ERROR)
             return None
 
         self.amphora_repo.update(db_apis.get_session(), amphora_id,
@@ -478,12 +512,19 @@ class AmphoraIndexVRRPUpdate(BaseAmphoraTask):
     """Task to update the VRRP configuration of an amphora."""
 
     def execute(self, loadbalancer_id, amphorae_network_config, amphora_index,
-                amphorae, amp_vrrp_int, timeout_dict=None):
+                amphorae, amphorae_status: dict, amp_vrrp_int: Optional[str],
+                new_amphora_id: str, timeout_dict=None):
         """Execute update_vrrp_conf."""
         # Note, we don't want this to cause a revert as it may be used
         # in a failover flow with both amps failing. Skip it and let
         # health manager fix it.
         amphora_id = amphorae[amphora_index][constants.ID]
+        amphora_status = amphorae_status.get(amphora_id, {})
+        if amphora_status.get(constants.UNREACHABLE):
+            LOG.warning("Skipping VRRP configuration because amphora %s "
+                        "is not reachable.", amphora_id)
+            return
+
         try:
             # TODO(johnsom) Optimize this to use the dicts and not need the
             #               DB lookups
@@ -498,8 +539,11 @@ class AmphoraIndexVRRPUpdate(BaseAmphoraTask):
             LOG.error('Failed to update VRRP configuration amphora %s. '
                       'Skipping this amphora as it is failing to update due '
                       'to: %s', amphora_id, str(e))
-            self.amphora_repo.update(db_apis.get_session(), amphora_id,
-                                     status=constants.ERROR)
+            # Update only the status of the newly created amphora during the
+            # failover
+            if amphora_id == new_amphora_id:
+                self.amphora_repo.update(db_apis.get_session(), amphora_id,
+                                         status=constants.ERROR)
             return
         LOG.debug("Uploaded VRRP configuration of amphora %s.", amphora_id)
 
@@ -525,10 +569,17 @@ class AmphoraIndexVRRPStart(BaseAmphoraTask):
     This will reload keepalived if it is already running.
     """
 
-    def execute(self, amphora_index, amphorae, timeout_dict=None):
+    def execute(self, amphora_index, amphorae, amphorae_status: dict,
+                new_amphora_id: str, timeout_dict=None):
         # TODO(johnsom) Optimize this to use the dicts and not need the
         #               DB lookups
         amphora_id = amphorae[amphora_index][constants.ID]
+        amphora_status = amphorae_status.get(amphora_id, {})
+        if amphora_status.get(constants.UNREACHABLE):
+            LOG.warning("Skipping VRRP start because amphora %s "
+                        "is not reachable.", amphora_id)
+            return
+
         db_amp = self.amphora_repo.get(db_apis.get_session(), id=amphora_id)
         try:
             self.amphora_driver.start_vrrp_service(db_amp, timeout_dict)
@@ -536,8 +587,11 @@ class AmphoraIndexVRRPStart(BaseAmphoraTask):
             LOG.error('Failed to start VRRP on amphora %s. '
                       'Skipping this amphora as it is failing to start due '
                       'to: %s', amphora_id, str(e))
-            self.amphora_repo.update(db_apis.get_session(), amphora_id,
-                                     status=constants.ERROR)
+            # Update only the status of the newly created amphora during the
+            # failover
+            if amphora_id == new_amphora_id:
+                self.amphora_repo.update(db_apis.get_session(), amphora_id,
+                                         status=constants.ERROR)
             return
         LOG.debug("Started VRRP on amphora %s.",
                   amphorae[amphora_index][constants.ID])
@@ -592,3 +646,40 @@ class AmphoraConfigUpdate(BaseAmphoraTask):
                       'update. Please update the amphora image for this '
                       'amphora. Skipping.'.
                       format(amphora.get(constants.ID)))
+
+
+class AmphoraeGetConnectivityStatus(BaseAmphoraTask):
+    """Task that checks amphorae connectivity status.
+
+    Check and return the connectivity status of both amphorae in ACTIVE STANDBY
+    load balancers
+    """
+
+    def execute(self, amphorae: List[dict], new_amphora_id: str,
+                timeout_dict=None):
+        amphorae_status = {}
+
+        for amphora in amphorae:
+            amphora_id = amphora[constants.ID]
+            amphorae_status[amphora_id] = {}
+
+            session = db_apis.get_session()
+            with session.begin():
+                db_amp = self.amphora_repo.get(session, id=amphora_id)
+
+            try:
+                # Verify if the amphora is reachable
+                self.amphora_driver.check(db_amp, timeout_dict=timeout_dict)
+            except Exception as e:
+                LOG.exception("Cannot get status for amphora %s",
+                              amphora_id)
+                # In case it fails and the tested amphora is the newly created
+                # amphora, it's not a normal error handling, re-raise the
+                # exception
+                if amphora_id == new_amphora_id:
+                    raise e
+                amphorae_status[amphora_id][constants.UNREACHABLE] = True
+            else:
+                amphorae_status[amphora_id][constants.UNREACHABLE] = False
+
+        return amphorae_status
