@@ -20,21 +20,16 @@ Create Date: 2015-07-20 15:25:37.044098
 
 """
 
+from alembic import op
+import sqlalchemy as sa
+
 # revision identifiers, used by Alembic.
 revision = '298eac0640a7'
 down_revision = '4fe8240425b4'
 
-from alembic import op
-import sqlalchemy as sa
-
 
 def upgrade():
     op.add_column(u'amphora',
                   sa.Column(u'vrrp_port_id', sa.String(36), nullable=True))
     op.add_column(u'amphora',
                   sa.Column(u'ha_port_id', sa.String(36), nullable=True))
-
-
-def downgrade():
-    op.drop_column(u'amphora', u'vrrp_port_id')
-    op.drop_column(u'amphora', u'ha_port_id')
