@@ -589,11 +589,10 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
                 load_balancer.amphorae):
             self.unplug_aap_port(vip, amphora, subnet)
 
-    def plug_network(self, compute_id, network_id, ip_address=None):
+    def plug_network(self, compute_id, network_id):
         try:
             interface = self.compute.attach_network_or_port(
-                compute_id=compute_id, network_id=network_id,
-                ip_address=ip_address)
+                compute_id=compute_id, network_id=network_id)
         except exceptions.NotFound as e:
             if 'Instance' in str(e):
                 raise base.AmphoraNotFound(str(e))
@@ -610,15 +609,14 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
 
         return self._nova_interface_to_octavia_interface(compute_id, interface)
 
-    def unplug_network(self, compute_id, network_id, ip_address=None):
+    def unplug_network(self, compute_id, network_id):
         interfaces = self.get_plugged_networks(compute_id)
         if not interfaces:
             msg = ('Amphora with compute id {compute_id} does not have any '
                    'plugged networks').format(compute_id=compute_id)
             raise base.NetworkNotFound(msg)
 
-        unpluggers = self._get_interfaces_to_unplug(interfaces, network_id,
-                                                    ip_address=ip_address)
+        unpluggers = self._get_interfaces_to_unplug(interfaces, network_id)
         removed_port_ids = set()
         for index, unplugger in enumerate(unpluggers):
             self.compute.detach_port(
