@@ -193,18 +193,19 @@ class BaseNeutronDriver(base.AbstractNetworkDriver):
                                resource_type)(resource_id)
             return getattr(utils, 'convert_%s_dict_to_model' %
                            resource_type)(resource)
-        except neutron_client_exceptions.NotFound:
+        except neutron_client_exceptions.NotFound as e:
             message = _('{resource_type} not found '
                         '({resource_type} id: {resource_id}).').format(
                 resource_type=resource_type, resource_id=resource_id)
             raise getattr(base, '%sNotFound' % ''.join(
-                [w.capitalize() for w in resource_type.split('_')]))(message)
-        except Exception:
+                [w.capitalize() for w in resource_type.split('_')]
+            ))(message) from e
+        except Exception as e:
             message = _('Error retrieving {resource_type} '
                         '({resource_type} id: {resource_id}.').format(
                 resource_type=resource_type, resource_id=resource_id)
             LOG.exception(message)
-            raise base.NetworkException(message)
+            raise base.NetworkException(message) from e
 
     def _get_resources_by_filters(self, resource_type, unique_item=False,
                                   **filters):
@@ -226,18 +227,19 @@ class BaseNeutronDriver(base.AbstractNetworkDriver):
 
             return list(map(conversion_function,
                             resource['%ss' % resource_type]))
-        except neutron_client_exceptions.NotFound:
+        except neutron_client_exceptions.NotFound as e:
             message = _('{resource_type} not found '
                         '({resource_type} Filters: {filters}.').format(
                 resource_type=resource_type, filters=filters)
             raise getattr(base, '%sNotFound' % ''.join(
-                [w.capitalize() for w in resource_type.split('_')]))(message)
-        except Exception:
+                [w.capitalize() for w in resource_type.split('_')]
+            ))(message) from e
+        except Exception as e:
             message = _('Error retrieving {resource_type} '
                         '({resource_type} Filters: {filters}.').format(
                 resource_type=resource_type, filters=filters)
             LOG.exception(message)
-            raise base.NetworkException(message)
+            raise base.NetworkException(message) from e
 
     def get_network(self, network_id, context=None):
         return self._get_resource('network', network_id, context=context)
@@ -273,3 +275,35 @@ class BaseNeutronDriver(base.AbstractNetworkDriver):
 
     def get_network_ip_availability(self, network):
         return self._get_resource('network_ip_availability', network.id)
+
+    def plug_fixed_ip(self, port_id, subnet_id, ip_address=None):
+        port = self.get_port(port_id).to_dict(recurse=True)
+        fixed_ips = port['fixed_ips']
+
+        new_fixed_ip_dict = {'subnet_id': subnet_id}
+        if ip_address:
+            new_fixed_ip_dict['ip_address'] = ip_address
+
+        fixed_ips.append(new_fixed_ip_dict)
+
+        body = {'port': {'fixed_ips': fixed_ips}}
+        try:
+            updated_port = self.neutron_client.update_port(port_id, body)
+            return utils.convert_port_dict_to_model(updated_port)
+        except Exception as e:
+            raise base.NetworkException(str(e))
+
+    def unplug_fixed_ip(self, port_id, subnet_id):
+        port = self.get_port(port_id)
+        fixed_ips = [
+            fixed_ip.to_dict()
+            for fixed_ip in port.fixed_ips
+            if fixed_ip.subnet_id != subnet_id
+        ]
+
+        body = {'port': {'fixed_ips': fixed_ips}}
+        try:
+            updated_port = self.neutron_client.update_port(port_id, body)
+            return utils.convert_port_dict_to_model(updated_port)
+        except Exception as e:
+            raise base.NetworkException(str(e))
