@@ -33,7 +33,7 @@ class TestAmphora(base.BaseAPITest):
     root_tag_stats = 'amphora_stats'
 
     def setUp(self):
-        super(TestAmphora, self).setUp()
+        super().setUp()
         self.lb = self.create_load_balancer(
             uuidutils.generate_uuid()).get('loadbalancer')
         self.lb_id = self.lb.get('id')
@@ -127,6 +127,104 @@ class TestAmphora(base.BaseAPITest):
             amphora_id=self.amp_id)).json.get(self.root_tag)
         self._assert_amp_equal(self.amp_args, response)
 
+    @mock.patch('oslo_messaging.RPCClient.cast')
+    def test_delete(self, mock_cast):
+        self.amp_args = {
+            'status': constants.AMPHORA_READY,
+        }
+        amp = self.amphora_repo.create(self.session, **self.amp_args)
+
+        self.delete(self.AMPHORA_PATH.format(
+            amphora_id=amp.id), status=204)
+
+        response = self.get(self.AMPHORA_PATH.format(
+            amphora_id=amp.id)).json.get(self.root_tag)
+
+        self.assertEqual(constants.PENDING_DELETE, response[constants.STATUS])
+
+        payload = {constants.AMPHORA_ID: amp.id}
+        mock_cast.assert_called_with({}, 'delete_amphora', **payload)
+
+    @mock.patch('oslo_messaging.RPCClient.cast')
+    def test_delete_not_found(self, mock_cast):
+        self.delete(self.AMPHORA_PATH.format(amphora_id='bogus-id'),
+                    status=404)
+        mock_cast.assert_not_called()
+
+    @mock.patch('oslo_messaging.RPCClient.cast')
+    def test_delete_immutable(self, mock_cast):
+        self.amp_args = {
+            'status': constants.AMPHORA_ALLOCATED,
+        }
+        amp = self.amphora_repo.create(self.session, **self.amp_args)
+
+        self.delete(self.AMPHORA_PATH.format(
+            amphora_id=amp.id), status=409)
+
+        mock_cast.assert_not_called()
+
+    @mock.patch('oslo_messaging.RPCClient.cast')
+    def test_delete_authorized(self, mock_cast):
+        self.amp_args = {
+            'status': constants.AMPHORA_READY,
+        }
+        amp = self.amphora_repo.create(self.session, **self.amp_args)
+
+        self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
+        auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
+        self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
+                               self.project_id):
+            override_credentials = {
+                'service_user_id': None,
+                'user_domain_id': None,
+                'is_admin_project': True,
+                'service_project_domain_id': None,
+                'service_project_id': None,
+                'roles': ['load-balancer_member'],
+                'user_id': None,
+                'is_admin': True,
+                'service_user_domain_id': None,
+                'project_domain_id': None,
+                'service_roles': [],
+                'project_id': self.project_id}
+            with mock.patch(
+                    "oslo_context.context.RequestContext.to_policy_values",
+                    return_value=override_credentials):
+                self.delete(self.AMPHORA_PATH.format(amphora_id=amp.id),
+                            status=204)
+        # Reset api auth setting
+        self.conf.config(group='api_settings', auth_strategy=auth_strategy)
+
+        response = self.get(self.AMPHORA_PATH.format(
+            amphora_id=amp.id)).json.get(self.root_tag)
+
+        self.assertEqual(constants.PENDING_DELETE, response[constants.STATUS])
+
+        payload = {constants.AMPHORA_ID: amp.id}
+        mock_cast.assert_called_with({}, 'delete_amphora', **payload)
+
+    @mock.patch('oslo_messaging.RPCClient.cast')
+    def test_delete_not_authorized(self, mock_cast):
+        self.amp_args = {
+            'status': constants.AMPHORA_READY,
+        }
+        amp = self.amphora_repo.create(self.session, **self.amp_args)
+
+        self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
+        auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
+        self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
+                               self.project_id):
+            self.delete(self.AMPHORA_PATH.format(amphora_id=amp.id),
+                        status=403)
+        # Reset api auth setting
+        self.conf.config(group='api_settings', auth_strategy=auth_strategy)
+
+        mock_cast.assert_not_called()
+
     @mock.patch('oslo_messaging.RPCClient.cast')
     def test_failover(self, mock_cast):
         self.put(self.AMPHORA_FAILOVER_PATH.format(
@@ -134,25 +232,6 @@ class TestAmphora(base.BaseAPITest):
         payload = {constants.AMPHORA_ID: self.amp_id}
         mock_cast.assert_called_with({}, 'failover_amphora', **payload)
 
-    @mock.patch('oslo_messaging.RPCClient.cast')
-    def test_failover_spare(self, mock_cast):
-        amp_args = {
-            'compute_id': uuidutils.generate_uuid(),
-            'status': constants.AMPHORA_READY,
-            'lb_network_ip': '192.168.1.2',
-            'cert_expiration': datetime.datetime.now(),
-            'cert_busy': False,
-            'cached_zone': 'zone1',
-            'created_at': datetime.datetime.now(),
-            'updated_at': datetime.datetime.now(),
-            'image_id': uuidutils.generate_uuid(),
-        }
-        amp = self.amphora_repo.create(self.session, **amp_args)
-        self.put(self.AMPHORA_FAILOVER_PATH.format(
-            amphora_id=amp.id), body={}, status=202)
-        payload = {constants.AMPHORA_ID: amp.id}
-        mock_cast.assert_called_once_with({}, 'failover_amphora', **payload)
-
     def test_failover_deleted(self):
         new_amp = self._create_additional_amp()
         self.amphora_repo.update(self.session, new_amp.id,
@@ -170,7 +249,8 @@ class TestAmphora(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                self.project_id):
             override_credentials = {
                 'service_user_id': None,
@@ -199,7 +279,8 @@ class TestAmphora(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                uuidutils.generate_uuid()):
             response = self.get(self.AMPHORA_PATH.format(
                 amphora_id=self.amp_id), status=403)
@@ -212,7 +293,8 @@ class TestAmphora(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                self.project_id):
             override_credentials = {
                 'service_user_id': None,
@@ -243,7 +325,8 @@ class TestAmphora(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                uuidutils.generate_uuid()):
             response = self.put(self.AMPHORA_FAILOVER_PATH.format(
                 amphora_id=self.amp_id), body={}, status=403)
@@ -272,7 +355,8 @@ class TestAmphora(base.BaseAPITest):
     def test_get_all_authorized(self):
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                uuidutils.generate_uuid()):
             override_credentials = {
                 'service_user_id': None,
@@ -301,7 +385,8 @@ class TestAmphora(base.BaseAPITest):
     def test_get_all_not_authorized(self):
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                uuidutils.generate_uuid()):
             amps = self.get(self.AMPHORAE_PATH, status=403).json
 
@@ -396,7 +481,7 @@ class TestAmphora(base.BaseAPITest):
         links = middle[self.root_tag_links]
         self.assertEqual(1, len(objs))
         self.assertEqual(2, len(links))
-        self.assertItemsEqual(['previous', 'next'],
+        self.assertCountEqual(['previous', 'next'],
                               [link['rel'] for link in links])
 
     def test_get_all_fields_filter(self):
@@ -434,7 +519,8 @@ class TestAmphora(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                self.project_id):
             override_credentials = {
                 'service_user_id': None,
@@ -462,7 +548,8 @@ class TestAmphora(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                uuidutils.generate_uuid()):
             response = self.get(self.AMPHORA_STATS_PATH.format(
                 amphora_id=self.amp_id), status=403)
@@ -533,32 +620,13 @@ class TestAmphora(base.BaseAPITest):
         self.put(self.AMPHORA_CONFIG_PATH.format(
             amphora_id=self.amp_id), body={}, status=500)
 
-    @mock.patch('oslo_messaging.RPCClient.cast')
-    def test_config_spare_amp(self, mock_cast):
-        amp_args = {
-            'compute_id': uuidutils.generate_uuid(),
-            'status': constants.AMPHORA_READY,
-            'lb_network_ip': '192.168.1.2',
-            'cert_expiration': datetime.datetime.now(),
-            'cert_busy': False,
-            'cached_zone': 'zone1',
-            'created_at': datetime.datetime.now(),
-            'updated_at': datetime.datetime.now(),
-            'image_id': uuidutils.generate_uuid(),
-        }
-        amp = self.amphora_repo.create(self.session, **amp_args)
-        self.put(self.AMPHORA_CONFIG_PATH.format(
-            amphora_id=amp.id), body={}, status=202)
-        payload = {constants.AMPHORA_ID: amp.id}
-        mock_cast.assert_called_with({}, 'update_amphora_agent_config',
-                                     **payload)
-
     @mock.patch('oslo_messaging.RPCClient.cast')
     def test_config_authorized(self, mock_cast):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                self.project_id):
             override_credentials = {
                 'service_user_id': None,
@@ -590,7 +658,8 @@ class TestAmphora(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                uuidutils.generate_uuid()):
             self.put(self.AMPHORA_CONFIG_PATH.format(
                 amphora_id=self.amp_id), body={}, status=403)
