@@ -30,7 +30,7 @@ class TestProvider(base.BaseAPITest):
     root_tag_list = 'providers'
 
     def setUp(self):
-        super(TestProvider, self).setUp()
+        super().setUp()
 
     def test_get_all_providers(self):
         octavia_dict = {u'description': u'Octavia driver.',
@@ -60,7 +60,7 @@ class TestFlavorCapabilities(base.BaseAPITest):
     root_tag = 'flavor_capabilities'
 
     def setUp(self):
-        super(TestFlavorCapabilities, self).setUp()
+        super().setUp()
 
     def test_nonexistent_provider(self):
         self.get(self.FLAVOR_CAPABILITIES_PATH.format(provider='bogus'),
@@ -102,7 +102,8 @@ class TestFlavorCapabilities(base.BaseAPITest):
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
         project_id = uuidutils.generate_uuid()
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                project_id):
             override_credentials = {
                 'service_user_id': None,
@@ -178,7 +179,7 @@ class TestAvailabilityZoneCapabilities(base.BaseAPITest):
     root_tag = 'availability_zone_capabilities'
 
     def setUp(self):
-        super(TestAvailabilityZoneCapabilities, self).setUp()
+        super().setUp()
 
     def test_nonexistent_provider(self):
         self.get(self.AVAILABILITY_ZONE_CAPABILITIES_PATH.format(
@@ -226,7 +227,8 @@ class TestAvailabilityZoneCapabilities(base.BaseAPITest):
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
         project_id = uuidutils.generate_uuid()
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
+        with mock.patch.object(octavia.common.context.RequestContext,
+                               'project_id',
                                project_id):
             override_credentials = {
                 'service_user_id': None,
