@@ -94,6 +94,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         self.fixed_ip = mock.MagicMock()
         self.fixed_ip.ip_address = '198.51.100.5'
         self.fixed_ip.subnet.cidr = '198.51.100.0/24'
+        self.fixed_ip.subnet.gateway_ip = FAKE_GATEWAY
         self.network = network_models.Network(mtu=FAKE_MTU)
         self.port = network_models.Port(mac_address=FAKE_MAC_ADDRESS,
                                         fixed_ips=[self.fixed_ip],
@@ -116,6 +117,9 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
                              constants.REQ_READ_TIMEOUT: 2,
                              constants.CONN_MAX_RETRIES: 3,
                              constants.CONN_RETRY_INTERVAL: 4}
+        self.amp_net_config = network_models.AmphoraNetworkConfig(
+            vip_subnet=self.lb.vip.subnet_id
+        )
 
     @mock.patch('octavia.amphorae.drivers.haproxy.rest_api_driver.'
                 'HaproxyAmphoraLoadBalancerDriver._process_secret')
@@ -488,6 +492,16 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
             API_VERSION].reload_listener.assert_called_once_with(
             amp1, listener.id, None)
 
+        self.driver.clients[
+            API_VERSION].reload_listener.reset_mock()
+        timeout_dict = {
+            'elem1': 1000
+        }
+        self.driver.reload(loadbalancer, timeout_dict=timeout_dict)
+        self.driver.clients[
+            API_VERSION].reload_listener.assert_called_once_with(
+            amp1, listener.id, timeout_dict)
+
     def test_start_with_amphora(self):
         # Execute driver method
         amp = mock.MagicMock()
@@ -589,6 +603,13 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         amphorae_network_config.get().vip_subnet.cidr = FAKE_CIDR
         amphorae_network_config.get().vip_subnet.gateway_ip = FAKE_GATEWAY
         amphorae_network_config.get().vip_subnet.host_routes = self.host_routes
+        amphorae_network_config.get().vip_subnet.to_dict.return_value = {
+            'cidr': FAKE_CIDR,
+            'gateway_ip': FAKE_GATEWAY,
+            'host_routes': [
+                hr.to_dict(recurse=True)
+                for hr in self.host_routes]
+        }
         amphorae_network_config.get().vrrp_port = self.port
         self.driver.post_vip_plug(self.amp, self.lb, amphorae_network_config)
         self.driver.clients[API_VERSION].plug_vip.assert_called_once_with(
@@ -599,7 +620,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         port = network_models.Port(mac_address=FAKE_MAC_ADDRESS,
                                    fixed_ips=[],
                                    network=self.network)
-        self.driver.post_network_plug(self.amp, port)
+        self.driver.post_network_plug(self.amp, port, self.amp_net_config)
         self.driver.clients[API_VERSION].plug_network.assert_called_once_with(
             self.amp, dict(mac_address=FAKE_MAC_ADDRESS,
                            fixed_ips=[],
@@ -608,12 +629,13 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         self.driver.clients[API_VERSION].plug_network.reset_mock()
 
         # Test fixed IP path
-        self.driver.post_network_plug(self.amp, self.port)
+        self.driver.post_network_plug(self.amp, self.port, self.amp_net_config)
         self.driver.clients[API_VERSION].plug_network.assert_called_once_with(
             self.amp, dict(mac_address=FAKE_MAC_ADDRESS,
                            fixed_ips=[dict(ip_address='198.51.100.5',
                                            subnet_cidr='198.51.100.0/24',
-                                           host_routes=[])],
+                                           host_routes=[],
+                                           gateway=FAKE_GATEWAY)],
                            mtu=FAKE_MTU))
 
     def test_post_network_plug_with_host_routes(self):
@@ -629,6 +651,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
                        network_models.HostRoute(destination=DEST2,
                                                 nexthop=NEXTHOP)]
         subnet = network_models.Subnet(id=SUBNET_ID, cidr=SUBNET_CIDR,
+                                       gateway_ip=FAKE_GATEWAY,
                                        ip_version=4, host_routes=host_routes)
         fixed_ips = [
             network_models.FixedIP(subnet_id=subnet.id, ip_address=FIXED_IP1,
@@ -639,12 +662,14 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         port = network_models.Port(mac_address=FAKE_MAC_ADDRESS,
                                    fixed_ips=fixed_ips,
                                    network=self.network)
-        self.driver.post_network_plug(self.amp, port)
+        self.driver.post_network_plug(self.amp, port, self.amp_net_config)
         expected_fixed_ips = [
             {'ip_address': FIXED_IP1, 'subnet_cidr': SUBNET_CIDR,
+             'gateway': FAKE_GATEWAY,
              'host_routes': [{'destination': DEST1, 'nexthop': NEXTHOP},
                              {'destination': DEST2, 'nexthop': NEXTHOP}]},
             {'ip_address': FIXED_IP2, 'subnet_cidr': SUBNET_CIDR,
+             'gateway': FAKE_GATEWAY,
              'host_routes': [{'destination': DEST1, 'nexthop': NEXTHOP},
                              {'destination': DEST2, 'nexthop': NEXTHOP}]}
         ]
@@ -657,7 +682,19 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         ref_haproxy_versions = ['1', '6']
         result = self.driver._get_haproxy_versions(self.amp)
         self.driver.clients[API_VERSION].get_info.assert_called_once_with(
-            self.amp)
+            self.amp, timeout_dict=None)
+        self.assertEqual(ref_haproxy_versions, result)
+
+    def test_get_haproxy_versions_with_timeout_dict(self):
+        ref_haproxy_versions = ['1', '6']
+        timeout_dict = {
+            constants.CONN_MAX_RETRIES: 100,
+            constants.CONN_RETRY_INTERVAL: 1
+        }
+        result = self.driver._get_haproxy_versions(self.amp,
+                                                   timeout_dict=timeout_dict)
+        self.driver.clients[API_VERSION].get_info.assert_called_once_with(
+            self.amp, timeout_dict=timeout_dict)
         self.assertEqual(ref_haproxy_versions, result)
 
     def test_populate_amphora_api_version(self):
@@ -751,6 +788,19 @@ class TestAmphoraAPIClientTest(base.TestCase):
         information = self.driver.get_info(self.amp)
         self.assertEqual(info, information)
 
+    @requests_mock.mock()
+    def test_get_info_with_timeout_dict(self, m):
+        info = {"hostname": "some_hostname", "version": "some_version",
+                "api_version": "0.5", "uuid": FAKE_UUID_1}
+        m.get("{base}/info".format(base=self.base_url_ver),
+              json=info)
+        timeout_dict = {
+            constants.CONN_MAX_RETRIES: 100,
+            constants.CONN_RETRY_INTERVAL: 1
+        }
+        information = self.driver.get_info(self.amp, timeout_dict=timeout_dict)
+        self.assertEqual(info, information)
+
     @requests_mock.mock()
     def test_get_info_unauthorized(self, m):
         m.get("{base}/info".format(base=self.base_url_ver),
