@@ -29,7 +29,7 @@ CONF = cfg.CONF
 class TestBarbicanACLAuth(base.TestCase):
 
     def setUp(self):
-        super(TestBarbicanACLAuth, self).setUp()
+        super().setUp()
         # Reset the client
         keystone._SESSION = None
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
@@ -91,5 +91,4 @@ class TestBarbicanACLAuth(base.TestCase):
         bc = acl_auth_object.get_barbican_client_user_auth(mock.Mock())
         self.assertTrue(hasattr(bc, 'containers') and
                         hasattr(bc.containers, 'register_consumer'))
-        self.assertEqual('publicURL', bc.client.interface)
-        self.assertEqual('RegionOne', bc.client.region_name)
+        self.assertEqual('public', bc.client.interface)
