@@ -11,9 +11,10 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+from unittest import mock
 
-import mock
 from oslo_utils import uuidutils
+import tenacity
 
 from octavia.common import constants
 from octavia.controller.worker import task_utils as task_utilities
@@ -37,7 +38,7 @@ class TestTaskUtils(base.TestCase):
         self.MEMBER_ID = uuidutils.generate_uuid()
         self.POOL_ID = uuidutils.generate_uuid()
 
-        super(TestTaskUtils, self).setUp()
+        super().setUp()
 
     @mock.patch('octavia.db.api.get_session', return_value=TEST_SESSION)
     @mock.patch('octavia.db.repositories.AmphoraRepository.update')
@@ -173,7 +174,13 @@ class TestTaskUtils(base.TestCase):
 
     @mock.patch('octavia.db.api.get_session', return_value=TEST_SESSION)
     @mock.patch('octavia.db.repositories.LoadBalancerRepository.update')
+    @mock.patch('tenacity.nap.time')
+    # mock LOG so we don't fill the console with log messages from
+    # tenacity.retry
+    @mock.patch('octavia.controller.worker.task_utils.LOG')
     def test_mark_loadbalancer_prov_status_active(self,
+                                                  mock_LOG,
+                                                  mock_time,
                                                   mock_lb_repo_update,
                                                   mock_get_session):
 
@@ -190,14 +197,41 @@ class TestTaskUtils(base.TestCase):
         mock_lb_repo_update.reset_mock()
         mock_get_session.side_effect = Exception('fail')
 
-        self.task_utils.mark_loadbalancer_prov_status_active(
+        self.assertRaises(
+            tenacity.RetryError,
+            self.task_utils.mark_loadbalancer_prov_status_active,
             self.LOADBALANCER_ID)
 
         self.assertFalse(mock_lb_repo_update.called)
 
+        # Exceptions then happy path
+        mock_get_session.reset_mock(side_effect=True)
+        mock_lb_repo_update.reset_mock()
+
+        mock_session = mock_get_session()
+        mock_get_session.side_effect = [
+            Exception('fail'),
+            Exception('fail'),
+            Exception('fail'),
+            mock_session]
+
+        self.task_utils.mark_loadbalancer_prov_status_active(
+            self.LOADBALANCER_ID)
+
+        mock_lb_repo_update.assert_called_once_with(
+            mock_session,
+            id=self.LOADBALANCER_ID,
+            provisioning_status=constants.ACTIVE)
+
     @mock.patch('octavia.db.api.get_session', return_value=TEST_SESSION)
     @mock.patch('octavia.db.repositories.LoadBalancerRepository.update')
+    @mock.patch('tenacity.nap.time')
+    # mock LOG so we don't fill the console with log messages from
+    # tenacity.retry
+    @mock.patch('octavia.controller.worker.task_utils.LOG')
     def test_mark_loadbalancer_prov_status_error(self,
+                                                 mock_LOG,
+                                                 mock_time,
                                                  mock_lb_repo_update,
                                                  mock_get_session):
 
@@ -214,10 +248,30 @@ class TestTaskUtils(base.TestCase):
         mock_lb_repo_update.reset_mock()
         mock_get_session.side_effect = Exception('fail')
 
+        self.assertRaises(tenacity.RetryError,
+                          self.task_utils.mark_loadbalancer_prov_status_error,
+                          self.LOADBALANCER_ID)
+
+        self.assertFalse(mock_lb_repo_update.called)
+
+        # Exceptions then happy path
+        mock_get_session.reset_mock(side_effect=True)
+        mock_lb_repo_update.reset_mock()
+
+        mock_session = mock_get_session()
+        mock_get_session.side_effect = [
+            Exception('fail'),
+            Exception('fail'),
+            Exception('fail'),
+            mock_session]
+
         self.task_utils.mark_loadbalancer_prov_status_error(
             self.LOADBALANCER_ID)
 
-        self.assertFalse(mock_lb_repo_update.called)
+        mock_lb_repo_update.assert_called_once_with(
+            mock_session,
+            id=self.LOADBALANCER_ID,
+            provisioning_status=constants.ERROR)
 
     @mock.patch('octavia.db.api.get_session', return_value=TEST_SESSION)
     @mock.patch('octavia.db.repositories.MemberRepository.update')
@@ -262,3 +316,22 @@ class TestTaskUtils(base.TestCase):
         self.task_utils.mark_pool_prov_status_error(self.POOL_ID)
 
         self.assertFalse(mock_pool_repo_update.called)
+
+    @mock.patch('octavia.db.api.get_session', return_value=TEST_SESSION)
+    @mock.patch('octavia.db.repositories.LoadBalancerRepository.get')
+    def test_get_current_loadbalancer_from_db(self, mock_lb_repo_get,
+                                              mock_get_session):
+        # Happy path
+        self.task_utils.get_current_loadbalancer_from_db(self.LOADBALANCER_ID)
+
+        mock_lb_repo_get.assert_called_once_with(
+            TEST_SESSION,
+            id=self.LOADBALANCER_ID)
+
+        # Exception path
+        mock_lb_repo_get.reset_mock()
+        mock_get_session.side_effect = Exception('fail')
+
+        self.task_utils.get_current_loadbalancer_from_db(self.POOL_ID)
+
+        self.assertFalse(mock_lb_repo_get.called)
