@@ -238,11 +238,12 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
         self.assertIn(constants.VIP, amp_flow.requires)
 
-        self.assertIn(constants.ADDED_PORTS, amp_flow.provides)
+        self.assertIn(constants.UPDATED_PORTS, amp_flow.provides)
         self.assertIn(constants.AMP_VRRP_INT, amp_flow.provides)
         self.assertIn(constants.AMPHORA, amp_flow.provides)
         self.assertIn(constants.AMPHORA_ID, amp_flow.provides)
         self.assertIn(constants.AMPHORAE, amp_flow.provides)
+        self.assertIn(constants.AMPHORAE_STATUS, amp_flow.provides)
         self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, amp_flow.provides)
         self.assertIn(constants.BASE_PORT, amp_flow.provides)
         self.assertIn(constants.COMPUTE_ID, amp_flow.provides)
@@ -253,7 +254,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.VIP_SG_ID, amp_flow.provides)
 
         self.assertEqual(7, len(amp_flow.requires))
-        self.assertEqual(13, len(amp_flow.provides))
+        self.assertEqual(14, len(amp_flow.provides))
 
     def test_get_failover_flow_standalone(self, mock_get_net_driver):
         failed_amphora = data_models.Amphora(
@@ -272,10 +273,11 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
         self.assertIn(constants.VIP, amp_flow.requires)
 
-        self.assertIn(constants.ADDED_PORTS, amp_flow.provides)
+        self.assertIn(constants.UPDATED_PORTS, amp_flow.provides)
         self.assertIn(constants.AMPHORA, amp_flow.provides)
         self.assertIn(constants.AMPHORA_ID, amp_flow.provides)
         self.assertIn(constants.AMPHORAE, amp_flow.provides)
+        self.assertIn(constants.AMPHORAE_STATUS, amp_flow.provides)
         self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, amp_flow.provides)
         self.assertIn(constants.BASE_PORT, amp_flow.provides)
         self.assertIn(constants.COMPUTE_ID, amp_flow.provides)
@@ -286,7 +288,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.VIP_SG_ID, amp_flow.provides)
 
         self.assertEqual(7, len(amp_flow.requires))
-        self.assertEqual(12, len(amp_flow.provides))
+        self.assertEqual(13, len(amp_flow.provides))
 
     def test_get_failover_flow_bogus_role(self, mock_get_net_driver):
         failed_amphora = data_models.Amphora(id=uuidutils.generate_uuid(),
@@ -324,12 +326,31 @@ class TestAmphoraFlows(base.TestCase):
 
         self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, vrrp_subflow.provides)
         self.assertIn(constants.AMP_VRRP_INT, vrrp_subflow.provides)
+        self.assertIn(constants.AMPHORAE_STATUS, vrrp_subflow.provides)
 
         self.assertIn(constants.LOADBALANCER_ID, vrrp_subflow.requires)
         self.assertIn(constants.AMPHORAE, vrrp_subflow.requires)
+        self.assertIn(constants.AMPHORA_ID, vrrp_subflow.requires)
+
+        self.assertEqual(3, len(vrrp_subflow.provides))
+        self.assertEqual(3, len(vrrp_subflow.requires))
+
+    def test_get_vrrp_subflow_dont_get_status(self, mock_get_net_driver):
+        vrrp_subflow = self.AmpFlow.get_vrrp_subflow('123',
+                                                     get_amphorae_status=False)
+
+        self.assertIsInstance(vrrp_subflow, flow.Flow)
+
+        self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, vrrp_subflow.provides)
+        self.assertIn(constants.AMP_VRRP_INT, vrrp_subflow.provides)
+
+        self.assertIn(constants.LOADBALANCER_ID, vrrp_subflow.requires)
+        self.assertIn(constants.AMPHORAE, vrrp_subflow.requires)
+        self.assertIn(constants.AMPHORA_ID, vrrp_subflow.requires)
+        self.assertIn(constants.AMPHORAE_STATUS, vrrp_subflow.requires)
 
         self.assertEqual(2, len(vrrp_subflow.provides))
-        self.assertEqual(2, len(vrrp_subflow.requires))
+        self.assertEqual(4, len(vrrp_subflow.requires))
 
     def test_get_vrrp_subflow_dont_create_vrrp_group(
             self, mock_get_net_driver):
@@ -340,12 +361,14 @@ class TestAmphoraFlows(base.TestCase):
 
         self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, vrrp_subflow.provides)
         self.assertIn(constants.AMP_VRRP_INT, vrrp_subflow.provides)
+        self.assertIn(constants.AMPHORAE_STATUS, vrrp_subflow.provides)
 
         self.assertIn(constants.LOADBALANCER_ID, vrrp_subflow.requires)
         self.assertIn(constants.AMPHORAE, vrrp_subflow.requires)
+        self.assertIn(constants.AMPHORA_ID, vrrp_subflow.requires)
 
-        self.assertEqual(2, len(vrrp_subflow.provides))
-        self.assertEqual(2, len(vrrp_subflow.requires))
+        self.assertEqual(3, len(vrrp_subflow.provides))
+        self.assertEqual(3, len(vrrp_subflow.requires))
 
     def test_get_post_map_lb_subflow(self, mock_get_net_driver):
 
@@ -430,7 +453,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.VIP, get_amp_flow.requires)
         self.assertIn(constants.VIP_SG_ID, get_amp_flow.requires)
 
-        self.assertIn(constants.ADDED_PORTS, get_amp_flow.provides)
+        self.assertIn(constants.UPDATED_PORTS, get_amp_flow.provides)
         self.assertIn(constants.AMPHORA, get_amp_flow.provides)
         self.assertIn(constants.AMPHORA_ID, get_amp_flow.provides)
         self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, get_amp_flow.provides)
@@ -460,7 +483,7 @@ class TestAmphoraFlows(base.TestCase):
         self.assertIn(constants.VIP, get_amp_flow.requires)
         self.assertIn(constants.VIP_SG_ID, get_amp_flow.requires)
 
-        self.assertIn(constants.ADDED_PORTS, get_amp_flow.provides)
+        self.assertIn(constants.UPDATED_PORTS, get_amp_flow.provides)
         self.assertIn(constants.AMPHORA, get_amp_flow.provides)
         self.assertIn(constants.AMPHORA_ID, get_amp_flow.provides)
         self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, get_amp_flow.provides)
