@@ -155,12 +155,17 @@ class TestLoadBalancerFlows(base.TestCase):
 
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
         self.assertIn(constants.UPDATE_DICT, amp_flow.requires)
+        self.assertIn(constants.AMPHORA_ID, amp_flow.requires)
+
+        self.assertIn(constants.AMPHORAE, amp_flow.provides)
+        self.assertIn(constants.AMPHORAE_STATUS, amp_flow.provides)
+        self.assertIn(constants.AMP_VRRP_INT, amp_flow.provides)
+        self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, amp_flow.provides)
         self.assertIn(constants.LOADBALANCER, amp_flow.provides)
 
-        self.assertEqual(4, len(amp_flow.provides))
-        self.assertEqual(2, len(amp_flow.requires))
+        self.assertEqual(5, len(amp_flow.provides))
+        self.assertEqual(3, len(amp_flow.requires))
 
-        # Test mark_active=False
         amp_flow = self.LBFlow.get_post_lb_amp_association_flow(
             '123', constants.TOPOLOGY_ACTIVE_STANDBY)
 
@@ -168,10 +173,16 @@ class TestLoadBalancerFlows(base.TestCase):
 
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
         self.assertIn(constants.UPDATE_DICT, amp_flow.requires)
+        self.assertIn(constants.AMPHORA_ID, amp_flow.requires)
+
+        self.assertIn(constants.AMPHORAE, amp_flow.provides)
+        self.assertIn(constants.AMPHORAE_STATUS, amp_flow.provides)
+        self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, amp_flow.provides)
+        self.assertIn(constants.AMP_VRRP_INT, amp_flow.provides)
         self.assertIn(constants.LOADBALANCER, amp_flow.provides)
 
-        self.assertEqual(4, len(amp_flow.provides))
-        self.assertEqual(2, len(amp_flow.requires))
+        self.assertEqual(5, len(amp_flow.provides))
+        self.assertEqual(3, len(amp_flow.requires))
 
     def test_get_create_load_balancer_flows_single_listeners(
             self, mock_get_net_driver):
@@ -183,22 +194,28 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertIsInstance(create_flow, flow.Flow)
         self.assertIn(constants.LOADBALANCER_ID, create_flow.requires)
         self.assertIn(constants.UPDATE_DICT, create_flow.requires)
+        self.assertIn(constants.BUILD_TYPE_PRIORITY, create_flow.requires)
+        self.assertIn(constants.FLAVOR, create_flow.requires)
+        self.assertIn(constants.AVAILABILITY_ZONE, create_flow.requires)
+        self.assertIn(constants.SERVER_GROUP_ID, create_flow.requires)
 
         self.assertIn(constants.LISTENERS, create_flow.provides)
+        self.assertIn(constants.SUBNET, create_flow.provides)
         self.assertIn(constants.AMPHORA, create_flow.provides)
         self.assertIn(constants.AMPHORA_ID, create_flow.provides)
         self.assertIn(constants.COMPUTE_ID, create_flow.provides)
         self.assertIn(constants.COMPUTE_OBJ, create_flow.provides)
         self.assertIn(constants.LOADBALANCER, create_flow.provides)
         self.assertIn(constants.DELTAS, create_flow.provides)
-        self.assertIn(constants.ADDED_PORTS, create_flow.provides)
+        self.assertIn(constants.UPDATED_PORTS, create_flow.provides)
         self.assertIn(constants.VIP, create_flow.provides)
         self.assertIn(constants.AMP_DATA, create_flow.provides)
+        self.assertIn(constants.SERVER_PEM, create_flow.provides)
         self.assertIn(constants.AMPHORA_NETWORK_CONFIG, create_flow.provides)
+        self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, create_flow.provides)
 
         self.assertEqual(6, len(create_flow.requires))
-        self.assertEqual(13, len(create_flow.provides),
-                         create_flow.provides)
+        self.assertEqual(14, len(create_flow.provides))
 
     def test_get_create_load_balancer_flows_active_standby_listeners(
             self, mock_get_net_driver):
@@ -214,18 +231,19 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertIn(constants.LISTENERS, create_flow.provides)
         self.assertIn(constants.AMPHORA, create_flow.provides)
         self.assertIn(constants.AMPHORA_ID, create_flow.provides)
+        self.assertIn(constants.AMPHORAE_STATUS, create_flow.provides)
         self.assertIn(constants.COMPUTE_ID, create_flow.provides)
         self.assertIn(constants.COMPUTE_OBJ, create_flow.provides)
         self.assertIn(constants.LOADBALANCER, create_flow.provides)
         self.assertIn(constants.DELTAS, create_flow.provides)
-        self.assertIn(constants.ADDED_PORTS, create_flow.provides)
+        self.assertIn(constants.UPDATED_PORTS, create_flow.provides)
         self.assertIn(constants.VIP, create_flow.provides)
         self.assertIn(constants.AMP_DATA, create_flow.provides)
         self.assertIn(constants.AMPHORAE_NETWORK_CONFIG,
                       create_flow.provides)
 
         self.assertEqual(6, len(create_flow.requires))
-        self.assertEqual(16, len(create_flow.provides),
+        self.assertEqual(17, len(create_flow.provides),
                          create_flow.provides)
 
     def _test_get_failover_LB_flow_single(self, amphorae):
@@ -243,7 +261,7 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertIn(constants.LOADBALANCER, failover_flow.requires)
         self.assertIn(constants.LOADBALANCER_ID, failover_flow.requires)
 
-        self.assertIn(constants.ADDED_PORTS, failover_flow.provides)
+        self.assertIn(constants.UPDATED_PORTS, failover_flow.provides)
         self.assertIn(constants.AMPHORA, failover_flow.provides)
         self.assertIn(constants.AMPHORA_ID, failover_flow.provides)
         self.assertIn(constants.AMPHORAE_NETWORK_CONFIG,
@@ -312,11 +330,12 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertIn(constants.LOADBALANCER, failover_flow.requires)
         self.assertIn(constants.LOADBALANCER_ID, failover_flow.requires)
 
-        self.assertIn(constants.ADDED_PORTS, failover_flow.provides)
+        self.assertIn(constants.UPDATED_PORTS, failover_flow.provides)
         self.assertIn(constants.AMP_VRRP_INT, failover_flow.provides)
         self.assertIn(constants.AMPHORA, failover_flow.provides)
         self.assertIn(constants.AMPHORA_ID, failover_flow.provides)
         self.assertIn(constants.AMPHORAE, failover_flow.provides)
+        self.assertIn(constants.AMPHORAE_STATUS, failover_flow.provides)
         self.assertIn(constants.AMPHORAE_NETWORK_CONFIG,
                       failover_flow.provides)
         self.assertIn(constants.BASE_PORT, failover_flow.provides)
@@ -334,7 +353,7 @@ class TestLoadBalancerFlows(base.TestCase):
 
         self.assertEqual(6, len(failover_flow.requires),
                          failover_flow.requires)
-        self.assertEqual(16, len(failover_flow.provides),
+        self.assertEqual(17, len(failover_flow.provides),
                          failover_flow.provides)
 
     def test_get_failover_LB_flow_no_amps_act_stdby(self, mock_get_net_driver):
