@@ -28,7 +28,7 @@ class TestLifecycleTasks(base.TestCase):
         self.AMPHORA.id = self.AMPHORA_ID
         self.HEALTH_MON = mock.MagicMock()
         self.HEALTH_MON_ID = uuidutils.generate_uuid()
-        self.HEALTH_MON.pool_id = self.HEALTH_MON_ID
+        self.HEALTH_MON.id = self.HEALTH_MON_ID
         self.L7POLICY = mock.MagicMock()
         self.L7POLICY_ID = uuidutils.generate_uuid()
         self.L7POLICY.id = self.L7POLICY_ID
@@ -51,7 +51,7 @@ class TestLifecycleTasks(base.TestCase):
         self.POOL_ID = uuidutils.generate_uuid()
         self.POOL.id = self.POOL_ID
 
-        super(TestLifecycleTasks, self).setUp()
+        super().setUp()
 
     @mock.patch('octavia.controller.worker.task_utils.TaskUtils.'
                 'unmark_amphora_health_busy')
