@@ -871,7 +871,10 @@ class TestAllowedAddressPairsDriver(base.TestCase):
 
     @mock.patch("time.time")
     @mock.patch("time.sleep")
-    def test_unplug_aap_port(self, mock_time_sleep, mock_time_time):
+    @mock.patch("octavia.network.drivers.neutron.allowed_address_pairs."
+                "AllowedAddressPairsDriver.unplug_network")
+    def test_unplug_aap_port(self, mock_unplug_network,
+                             mock_time_sleep, mock_time_time):
         lb = dmh.generate_load_balancer_tree()
         update_port = self.driver.neutron_client.update_port
         port1 = t_constants.MOCK_NEUTRON_PORT['port']
@@ -894,6 +897,8 @@ class TestAllowedAddressPairsDriver(base.TestCase):
         self.driver.unplug_aap_port(lb.vip, lb.amphorae[0], subnet)
         clear_aap = {'port': {'allowed_address_pairs': []}}
         update_port.assert_called_once_with(port2.get('id'), clear_aap)
+        mock_unplug_network.assert_called_once_with(
+            lb.amphorae[0].compute_id, subnet.network_id)
 
     def test_plug_network_when_compute_instance_cant_be_found(self):
         net_id = t_constants.MOCK_NOVA_INTERFACE.net_id
